@@ -41,9 +41,9 @@
 
 struct _BjbControllerPrivate
 {
-  BijiNoteBook   *book ;
+  BijiManager   *manager ;
   gchar          *needle ;
-  BijiCollection *collection;
+  BijiNotebook *notebook;
   GtkTreeModel   *model ;
 
   BjbWindowBase  *window;
@@ -55,7 +55,7 @@ struct _BjbControllerPrivate
   GMutex          mutex;
 
   gboolean        connected;
-  gulong          book_change;
+  gulong          manager_change;
 };
 
 
@@ -73,7 +73,7 @@ static GParamSpec *properties[NUM_PROPERTIES] = { NULL, };
 /* Currently used by toolbars */
 enum {
   SEARCH_CHANGED,
-  DISPLAY_NOTES_CHANGED, // either search or book change
+  DISPLAY_NOTES_CHANGED, // either search or manager change
   BJB_CONTROLLER_SIGNALS
 };
 
@@ -109,7 +109,7 @@ bjb_controller_init (BjbController *self)
   priv->items_to_show = NULL;
   priv->n_items_to_show = BJB_ITEMS_SLICE;
   priv->needle = NULL;
-  priv->collection = NULL;
+  priv->notebook = NULL;
   priv->connected = FALSE;
 
 }
@@ -132,8 +132,8 @@ bjb_controller_finalize (GObject *object)
   g_free (priv->needle);
   g_list_free (priv->items_to_show);
 
-  if (priv->collection)
-    g_free (priv->collection);
+  if (priv->notebook)
+    g_free (priv->notebook);
 
   G_OBJECT_CLASS (bjb_controller_parent_class)->finalize (object);
 }
@@ -149,7 +149,7 @@ bjb_controller_get_property (GObject  *object,
   switch (property_id)
   {
   case PROP_BOOK:
-    g_value_set_object (value, self->priv->book);
+    g_value_set_object (value, self->priv->manager);
     break;
   case PROP_WINDOW:
     g_value_set_object (value, self->priv->window);
@@ -177,7 +177,7 @@ bjb_controller_set_property (GObject  *object,
   switch (property_id)
   {
   case PROP_BOOK:
-    bjb_controller_set_book(self,g_value_get_object(value));
+    bjb_controller_set_manager(self,g_value_get_object(value));
     break;
   case PROP_WINDOW:
     self->priv->window = g_value_get_object (value);
@@ -222,7 +222,7 @@ bjb_controller_get_iter (BjbController *self,
 
     /* Else we check for the first note */
     else if (!needle && BIJI_IS_NOTE_OBJ (
-              biji_note_book_get_item_at_path (self->priv->book, item_path)))
+              biji_manager_get_item_at_path (self->priv->manager, item_path)))
       retval = TRUE;
 
     g_free (item_path);
@@ -315,10 +315,10 @@ bjb_controller_add_item_if_needed (BjbController *self,
   /* No search - we add the note */
   if (!priv->needle || g_strcmp0 (priv->needle, "")==0)
   {
-    if (!priv->collection)
+    if (!priv->notebook)
       need_to_add_item = TRUE;
 
-    /* To do : we might have a collection
+    /* To do : we might have a notebook
      * but have to udpate the view */
   }
 
@@ -352,20 +352,20 @@ most_recent_item_first (gconstpointer a, gconstpointer b)
   BijiItem *other = BIJI_ITEM (b);
   glong result = 0;
 
-  /* Always sort collections before notes */
-  if (BIJI_IS_COLLECTION (a))
+  /* Always sort notebooks before notes */
+  if (BIJI_IS_NOTEBOOK (a))
   {
     if (BIJI_IS_NOTE_OBJ (b))
       result = -1;
   }
 
-  else if (BIJI_IS_COLLECTION (b))
+  else if (BIJI_IS_NOTEBOOK (b))
   {
     result = 1;
   }
 
   /* If comparing two notes or
-   * two collections, use the most recent cookbook */
+   * two notebooks, use the most recent cookbook */
   else
   {
     result =   biji_item_get_mtime (other)
@@ -487,7 +487,7 @@ bjb_controller_apply_needle (BjbController *self)
   /* Show all notes */
   if (needle == NULL || g_strcmp0 (needle,"") == 0)
   {
-    all_notes = biji_note_book_get_items (self->priv->book);
+    all_notes = biji_manager_get_items (self->priv->manager);
 
     /* If there are no note, report this */
     if (all_notes == NULL)
@@ -502,7 +502,7 @@ bjb_controller_apply_needle (BjbController *self)
   }
 
   /* There is a research, apply lookup */
-  biji_get_items_matching_async (self->priv->book, needle, update_controller_callback, self);
+  biji_get_items_matching_async (self->priv->manager, needle, update_controller_callback, self);
 }
 
 static void
@@ -516,14 +516,13 @@ on_needle_changed (BjbController *self)
 /* Depending on the change at data level,
  * the view has to be totaly refreshed or just amended */
 static void
-on_book_changed (BijiNoteBook           *book,
-                 BijiNoteBookChangeFlag  flag,
+on_manager_changed (BijiManager           *manager,
+                 BijiManagerChangeFlag  flag,
                  gpointer               *biji_item,
                  BjbController          *self)
 {
   BjbControllerPrivate *priv = self->priv;
   BijiItem    *item = BIJI_ITEM (biji_item);
-  BijiNoteObj *note = NULL;
   GtkTreeIter iter;
   GtkTreeIter *p_iter = &iter;
 
@@ -532,11 +531,11 @@ on_book_changed (BijiNoteBook           *book,
   switch (flag)
   {
     /* If this is a *new* item, per def prepend */
-    case BIJI_BOOK_ITEM_ADDED:
+    case BIJI_MANAGER_ITEM_ADDED:
           if (BIJI_IS_NOTE_OBJ (item))
             bjb_controller_get_iter (self, NULL, &p_iter);
 
-          else if (BIJI_IS_COLLECTION (item))
+          else if (BIJI_IS_NOTEBOOK (item))
             p_iter = NULL;
 
           bjb_controller_add_item_if_needed (self, item, TRUE, p_iter);
@@ -545,8 +544,8 @@ on_book_changed (BijiNoteBook           *book,
           notify_displayed_items_changed (self);
       break;
 
-    /* Same comment, prepend but collection before note */
-    case BIJI_BOOK_NOTE_AMENDED:
+    /* Same comment, prepend but notebook before note */
+    case BIJI_MANAGER_NOTE_AMENDED:
       if (bjb_controller_get_iter (self, item, &p_iter))
       {
         gtk_list_store_remove (GTK_LIST_STORE (priv->model), p_iter);
@@ -554,7 +553,7 @@ on_book_changed (BijiNoteBook           *book,
         if (BIJI_IS_NOTE_OBJ (item))
           bjb_controller_get_iter (self, NULL, &p_iter);
 
-        else if (BIJI_IS_COLLECTION (item))
+        else if (BIJI_IS_NOTEBOOK (item))
           p_iter = NULL;
 
         bjb_controller_add_item_if_needed (self, item, TRUE, p_iter);
@@ -562,7 +561,7 @@ on_book_changed (BijiNoteBook           *book,
       break;
 
     /* If color changed we just amend the icon */
-    case BIJI_BOOK_ITEM_ICON_CHANGED:
+    case BIJI_MANAGER_ITEM_ICON_CHANGED:
       if (bjb_main_view_get_view_type (
              bjb_window_base_get_main_view (self->priv->window)) == GD_MAIN_VIEW_ICON
           && bjb_controller_get_iter (self, item, &p_iter))
@@ -575,17 +574,17 @@ on_book_changed (BijiNoteBook           *book,
                             GD_MAIN_COLUMN_ICON, biji_item_get_emblem (item), -1);
       break;
 
-    case BIJI_BOOK_ITEM_TRASHED:
+    case BIJI_MANAGER_ITEM_TRASHED:
       if (bjb_controller_get_iter (self, item, &p_iter))
         gtk_list_store_remove (GTK_LIST_STORE (priv->model), p_iter);
 
-      priv->items_to_show = g_list_remove (priv->items_to_show, note);
+      priv->items_to_show = g_list_remove (priv->items_to_show, item);
       notify_displayed_items_changed (self);
       break;
 
     default:
       bjb_controller_apply_needle (self);
-      if (flag == BIJI_BOOK_MASS_CHANGE)
+      if (flag == BIJI_MANAGER_MASS_CHANGE)
         bjb_window_base_set_active (self->priv->window, TRUE);
   }
 
@@ -599,8 +598,8 @@ bjb_controller_connect (BjbController *self)
   
   if (!priv->connected)
   {
-    priv->book_change = g_signal_connect (self->priv->book, "changed",
-                                     G_CALLBACK(on_book_changed), self);
+    priv->manager_change = g_signal_connect (self->priv->manager, "changed",
+                                     G_CALLBACK(on_manager_changed), self);
     priv->connected = TRUE;
   }
 
@@ -612,8 +611,8 @@ bjb_controller_disconnect (BjbController *self)
 {
   BjbControllerPrivate *priv = self->priv;
 
-  g_signal_handler_disconnect (priv->book, priv->book_change);
-  priv->book_change = 0;
+  g_signal_handler_disconnect (priv->manager, priv->manager_change);
+  priv->manager_change = 0;
 }
 
 static void
@@ -658,10 +657,10 @@ bjb_controller_class_init (BjbControllerClass *klass)
                                                   G_TYPE_BOOLEAN,
                                                   G_TYPE_BOOLEAN);
 
-  properties[PROP_BOOK] = g_param_spec_object ("book",
+  properties[PROP_BOOK] = g_param_spec_object ("manager",
                                                "Book",
-                                               "The BijiNoteBook",
-                                               BIJI_TYPE_NOTE_BOOK,
+                                               "The BijiManager",
+                                               BIJI_TYPE_MANAGER,
                                                G_PARAM_READWRITE |
                                                G_PARAM_CONSTRUCT |
                                                G_PARAM_STATIC_STRINGS);
@@ -695,21 +694,21 @@ bjb_controller_class_init (BjbControllerClass *klass)
 }
 
 BjbController *
-bjb_controller_new (BijiNoteBook  *book,
+bjb_controller_new (BijiManager  *manager,
                     GtkWindow     *window,
                     gchar         *needle)
 {
   return g_object_new ( BJB_TYPE_CONTROLLER,
-              "book", book,
+              "manager", manager,
               "window", window,
               "needle", needle,
               NULL); 
 }
 
 void
-bjb_controller_set_book (BjbController *self, BijiNoteBook  *book )
+bjb_controller_set_manager (BjbController *self, BijiManager  *manager )
 {
-  self->priv->book = book ;
+  self->priv->manager = manager ;
 }
 
 void
@@ -744,37 +743,37 @@ bjb_controller_shows_item (BjbController *self)
   return (self->priv->items_to_show != NULL);
 }
 
-BijiCollection *
-bjb_controller_get_collection (BjbController *self)
+BijiNotebook *
+bjb_controller_get_notebook (BjbController *self)
 {
-  return self->priv->collection;
+  return self->priv->notebook;
 }
 
 
 void
-bjb_controller_set_collection (BjbController *self,
-                               BijiCollection *coll)
+bjb_controller_set_notebook (BjbController *self,
+                               BijiNotebook *coll)
 {
-  /* Going back from a collection */
+  /* Going back from a notebook */
   if (!coll)
   {
-    if (!self->priv->collection)
+    if (!self->priv->notebook)
       return;
 
     bjb_window_base_switch_to (self->priv->window, BJB_WINDOW_BASE_SPINNER_VIEW);
-    self->priv->collection = NULL;
+    self->priv->notebook = NULL;
     bjb_controller_apply_needle (self);
     return;
   }
 
-  /* Opening an __existing__ collection */
+  /* Opening an __existing__ notebook */
   bjb_window_base_switch_to (self->priv->window, BJB_WINDOW_BASE_SPINNER_VIEW);
   g_clear_pointer (&self->priv->items_to_show, g_list_free);
   g_clear_pointer (&self->priv->needle, g_free);
 
   self->priv->needle = g_strdup ("");
-  self->priv->collection = coll;
-  biji_get_items_with_collection_async (self->priv->book,
+  self->priv->notebook = coll;
+  biji_get_items_with_notebook_async (self->priv->manager,
                                         biji_item_get_title (BIJI_ITEM (coll)),
                                         update_controller_callback,
                                         self);
@@ -788,8 +787,8 @@ bjb_controller_show_more (BjbController *self)
 
   /* FIXME: this method to refresh is just non sense */
 
-  if (self->priv->collection != NULL)
-    bjb_controller_set_collection (self, self->priv->collection);
+  if (self->priv->notebook != NULL)
+    bjb_controller_set_notebook (self, self->priv->notebook);
 
   else
     on_needle_changed (self);
