@@ -21,7 +21,7 @@
 #include "bjb-bijiben.h"
 #include "bjb-color-button.h"
 #include "bjb-main-toolbar.h"
-#include "bjb-note-tag-dialog.h"
+#include "bjb-organize-dialog.h"
 #include "bjb-rename-note.h"
 #include "bjb-share.h"
 #include "bjb-window-base.h"
@@ -107,13 +107,13 @@ static void
 on_new_note_clicked (GtkWidget *but, BjbMainView *view)
 {
   BijiNoteObj *result;
-  BijiNoteBook *book;
+  BijiManager *manager;
   BjbSettings  *settings;
 
-  /* append note to collection */
-  book = bjb_window_base_get_book (bjb_main_view_get_window (view));
+  /* append note to notebook */
+  manager = bjb_window_base_get_manager (bjb_main_view_get_window (view));
   settings = bjb_app_get_settings (g_application_get_default ());
-  result = biji_note_book_note_new (book,
+  result = biji_manager_note_new (manager,
                                     NULL,
                                     bjb_settings_get_default_location (settings));
 
@@ -257,7 +257,7 @@ add_search_button (BjbMainToolbar *self)
                                "image-button");
   gtk_header_bar_pack_end (GTK_HEADER_BAR (self), priv->search);
   gtk_widget_set_tooltip_text (priv->search,
-                               _("Search note titles, content and collections"));
+                               _("Search note titles, content and notebooks"));
 
   active =  bjb_window_base_get_show_search_bar (BJB_WINDOW_BASE (self->priv->window));
   gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (priv->search), active);
@@ -330,10 +330,10 @@ static void
 update_label_for_standard (BjbMainToolbar *self)
 {
   BjbMainToolbarPrivate *priv = self->priv;
-  BijiCollection *coll;
+  BijiNotebook *coll;
   gchar *needle, *label;
 
-  coll = bjb_controller_get_collection (priv->controller);
+  coll = bjb_controller_get_notebook (priv->controller);
   needle = bjb_controller_get_needle (priv->controller);
 
   if (coll)
@@ -372,14 +372,14 @@ connect_main_view_handlers (BjbMainToolbar *self)
 static void
 on_back_button_clicked (BjbMainToolbar *self)
 {
-  bjb_controller_set_collection (self->priv->controller, NULL);
+  bjb_controller_set_notebook (self->priv->controller, NULL);
 }
 
 static void
 populate_bar_for_standard(BjbMainToolbar *self)
 {
   BjbMainToolbarPrivate *priv = self->priv;
-  BijiCollection *coll;
+  BijiNotebook *coll;
   GtkWidget *select_image;
   gboolean rtl;
   GtkSizeGroup *size;
@@ -392,7 +392,7 @@ populate_bar_for_standard(BjbMainToolbar *self)
          "search-changed", G_CALLBACK(update_label_for_standard), self);
 
   /* Go back to all notes */
-  coll = bjb_controller_get_collection (priv->controller);
+  coll = bjb_controller_get_notebook (priv->controller);
 
   if (coll != NULL)
   {
@@ -460,7 +460,7 @@ populate_bar_for_icon_view(BjbMainToolbar *self)
                                "image-button");
   gtk_header_bar_pack_end (GTK_HEADER_BAR (self), priv->list);
   gtk_widget_set_tooltip_text (priv->list,
-                               _("View notes and collections in a list"));
+                               _("View notes and notebooks in a list"));
 
   g_signal_connect (priv->list, "clicked",
                     G_CALLBACK(on_view_mode_clicked),self);
@@ -484,7 +484,7 @@ populate_bar_for_list_view(BjbMainToolbar *self)
                                "image-button");
   gtk_header_bar_pack_end (GTK_HEADER_BAR (self), priv->grid);
   gtk_widget_set_tooltip_text (priv->grid,
-                               _("View notes and collections in a grid"));
+                               _("View notes and notebooks in a grid"));
 
   g_signal_connect (priv->grid, "clicked",
                     G_CALLBACK(on_view_mode_clicked),self);
@@ -520,11 +520,16 @@ just_switch_to_main_view (BjbMainToolbar *self)
 }
 
 static void
-on_note_renamed (BijiNoteObj *note,
+on_note_renamed (BijiItem *note,
                  BjbMainToolbar *self)
 {
-  gtk_header_bar_set_title (GTK_HEADER_BAR (self),
-                            biji_item_get_title (BIJI_ITEM (note)));
+  const gchar *str;
+
+  str = biji_item_get_title (note);
+  if (str == NULL)
+    str = _("Untitled");
+
+  gtk_header_bar_set_title (GTK_HEADER_BAR (self), str);
   gtk_header_bar_set_subtitle (GTK_HEADER_BAR (self), NULL);
 }
 
@@ -584,7 +589,7 @@ action_view_tags_callback (GtkWidget *item, gpointer user_data)
   GList *list = NULL;
 
   list = g_list_append (list, self->priv->note);
-  bjb_note_tag_dialog_new (self->priv->window, list);
+  bjb_organize_dialog_new (self->priv->window, list);
   g_list_free (list);
 }
 
@@ -593,10 +598,10 @@ delete_item_callback (GtkWidget *item, gpointer user_data)
 {
   BjbMainToolbar *self = BJB_MAIN_TOOLBAR (user_data);
 
-  /* Delete the note from collection
+  /* Delete the note from notebook
    * The deleted note will emit a signal. */
-  biji_note_book_remove_item (
-          bjb_window_base_get_book (GTK_WIDGET (self->priv->window)),
+  biji_manager_remove_item (
+          bjb_window_base_get_manager (GTK_WIDGET (self->priv->window)),
           BIJI_ITEM (self->priv->note));
 }
 
@@ -656,7 +661,7 @@ bjb_note_menu_new (BjbMainToolbar *self)
 
   if (biji_item_is_collectable (BIJI_ITEM (priv->note)))
   {
-    item = gtk_menu_item_new_with_label(_("Collections"));
+    item = gtk_menu_item_new_with_label(_("Notebooks"));
     gtk_menu_shell_append(GTK_MENU_SHELL(result),item);
     g_signal_connect(item,"activate",
                      G_CALLBACK(action_view_tags_callback),self);
@@ -707,10 +712,7 @@ populate_bar_for_note_view (BjbMainToolbar *self)
                               GDK_KEY_w, GDK_CONTROL_MASK, GTK_ACCEL_MASK);
 
   /* Note Title */
-
-  gtk_header_bar_set_title (bar, biji_item_get_title (item));
-  gtk_header_bar_set_subtitle (bar, NULL);
-
+  on_note_renamed (item, self);
   self->priv->note_renamed = g_signal_connect (priv->note,"renamed",
                                     G_CALLBACK (on_note_renamed), self);
 
