@@ -25,8 +25,8 @@
 #include <libgd/gd.h>
 
 #include "bjb-color-button.h"
-#include "bjb-note-tag-dialog.h"
 #include "bjb-main-view.h"
+#include "bjb-organize-dialog.h"
 #include "bjb-selection-toolbar.h"
 #include "bjb-window-base.h"
 
@@ -104,7 +104,7 @@ action_tag_selected_items (GtkWidget *w, BjbSelectionToolbar *self)
   GList *selection;
 
   selection = bjb_main_view_get_selected_items (self->priv->view);
-  bjb_note_tag_dialog_new
+  bjb_organize_dialog_new
     (GTK_WINDOW (bjb_main_view_get_window (self->priv->view)), selection);
 
   bjb_main_view_set_selection_mode (self->priv->view, FALSE);
@@ -116,14 +116,14 @@ static void
 action_delete_selected_items (GtkWidget *w, BjbSelectionToolbar *self)
 {
   GList *l, *selection;
-  BijiNoteBook *book;
+  BijiManager *manager;
 
   selection = bjb_main_view_get_selected_items (self->priv->view);
-  book = bjb_window_base_get_book (bjb_main_view_get_window (self->priv->view));
+  manager = bjb_window_base_get_manager (bjb_main_view_get_window (self->priv->view));
 
   for (l=selection; l !=NULL; l=l->next)
   {
-    biji_note_book_remove_item (book, BIJI_ITEM (l->data));
+    biji_manager_remove_item (manager, BIJI_ITEM (l->data));
   }
 
   bjb_main_view_set_selection_mode (self->priv->view, FALSE);
@@ -255,7 +255,7 @@ bjb_selection_toolbar_init (BjbSelectionToolbar *self)
 
 
   /* Notes tags */
-  priv->toolbar_tag = gtk_button_new_with_label (_("Add to Collection"));
+  priv->toolbar_tag = gtk_button_new_with_label (_("Notebooks"));
   gtk_widget_set_valign (priv->toolbar_tag, GTK_ALIGN_CENTER);
   gtk_header_bar_pack_end (priv->bar, priv->toolbar_tag);
 
